#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 emojis
version:              0.1.4.1
visibility:           public
id:                   emojis-0.1.4.1-6u64yT2pV06CQZyuF8uOZ1
key:                  emojis-0.1.4.1-6u64yT2pV06CQZyuF8uOZ1
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  eef161ee0c2dad627767a48424fb8439
exposed:              True
exposed-modules:      Text.Emoji
hidden-modules:       Trie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.4.1-6u64yT2pV06CQZyuF8uOZ1
depends:              base-4.18.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

